
/*
tutorial_#5-07

=====================
Six Online Tutorials:
=====================

The tutorials online propose ideas and approaches, which allow the user to problematize and then practice to do something to use for their own purposes.
Describes the stages of construction of some systems to help the reader, step by step, to learn to do something, to build patchs be used effectively in the performance.
Examples are some ideas to change, expand, or start from scratch using the same ideas or the same solutions and then realize their control systems.

=====================
ONLINE TUTORIAL #5
5. "CLUSTER" (by E.Francioni) - example of live electronics based on timing.
=====================

Finally, unlike the previous tutorial_#5-06, in this tutorial_#5-07 was added spatial quadraphonic signal and its control in the GUI.
N.B. For successful execution of the algorithm with spatial 4-channel [nchnls = 4] is necessary to interface a sound card to 4 output channels and one input channel; alternatively it is important to keep nchnls = 2.

Some observations:
     for orchestra
     - You add the code to the spatial signal in a quadraphonic sound system;

     in the Widgets Panel is given the opportunity to:
     - View the location of the signal (in Real-time and Deferred-time) within the space quadraphonic, through the two respective Controllers (RT-SPACE and DEL-SPACE): the first dedicated to the representation of spatial signal in Real-timeand the second in Deferred time.

*/

<CsoundSynthesizer>
<CsOptions>
</CsOptions>
<CsInstruments>

; header
sr		=	44100
ksmps		=	64
nchnls_i	=	1
nchnls		=	2
;nchnls		=	4
0dbfs		=	1

gkPlay		init	0
gkin		init	0
gaSIG		init	0
gktinstr		init	0
gkmtr1		init	0
gkmtr2		init	0
gkcdwn	init	0
gkph		init	0
gkx		init	0
gky		init	0
gkxD		init	0
gkyD		init	0

;=======================================
	instr	Play	; caller	instrument
;=======================================

gkPlay	= 1 - gkPlay

	schedkwhen		gkPlay, -1, 1, 1, i(gkcdwn), 10
	schedkwhen		gkPlay, -1, 1, 2, i(gkcdwn),  10
	schedkwhen		gkPlay, -1, 1, 3, 0, 10+i(gkcdwn)
	schedkwhen		gkPlay, -1, 1, 4, 0, 10+i(gkcdwn)
	schedkwhen		gkPlay, -1, 1, 5, i(gkcdwn),  10		
	turnoff
	
	endin
		
		
;=======================================
	instr	1	; signal processing
;=======================================

if gkPlay != 0 goto cont
turnoff
cont:

if 		gkin	== 0 then
aSIG		soundin	"demo.wav"
else
aSIG		inch	1
endif

; SILENCE
if 	(gktinstr >= 0) && (gktinstr < 3)	then
kx	=	10						; x value - out of range
ky	=	10						; y value - out of range
outvalue	"capture", 0
kgaincb	=	0

; SOUND + CAPTURE + FX
elseif	(gktinstr >= 3) && (gktinstr < 6)	then
kx	=	1						; x value - in the range
ky	=	1						; y value - in the range
outvalue	"capture", 1
aosc	oscili	1, 300, 1
aRM	=	aSIG*(aosc*4)	; RM
gaSIG	=	aSIG
kgaincb	=	1

; SILENCE
elseif 	(gktinstr >= 6) && (gktinstr <= 10) 	then
kx	=	10						; x value - out of range
ky	=	10						; y value - out of range
outvalue	"capture", 0
kgaincb	=	0

endif

; SPATIALIZATION
ktime		line	0, p3, p3
gkx	=	kx				; globalization of values kx
gky	=	ky				; globalization of values ky

a1, a2, a3, a4		space		aRM*kgaincb, 0, ktime, 0, kx, ky

outch	1, a1, 2, a2, 3, a3, 4, a4

	endin

;=======================================
	instr	2	; signal revived
;=======================================

if gkPlay != 0 goto cont
turnoff
cont:
    
adelay	delay	gaSIG, 4

; SILENCE
if 	(gktinstr >= 0) && (gktinstr < 7)	then
kx	=	10						; x value - out of range
ky	=	10						; y value - out of range
outvalue	"revived", 0
kgaincb	=	0

; SOUND DELAY+ REVIVED
elseif 	(gktinstr >= 7) && (gktinstr <= 10) then
kx	=	-1						; x value - in the range
ky	=	1						; y value - in the range
outvalue	"revived", 1
kgaincb	=	1

endif

; SPATIALIZATION
ktime		line	0, p3, p3
gkxD	=	kx				; globalization of values kx
gkyD	=	ky				; globalization of values ky

a1, a2, a3, a4		space		adelay*kgaincb, 0, ktime, 0, kx, ky

outch	1, a1, 2, a2, 3, a3, 4, a4
clear	gaSIG

	endin

;=======================================
	instr	3	; metronome
;=======================================

if gkPlay != 0 goto cont
turnoff
cont:

ktinstr	timeinsts
kphsr 	phasor	 1

if kphsr >= .0009 && kphsr <= .2 then
	if	gkcdwn > 0 && ktinstr < gkcdwn then
	gkmtr2		=	1
	gkmtr1 	=	0
	else
	gkmtr2 	=	0
	gkmtr1 	=	1
	endif
	
else
gkmtr2		=	0		
gkmtr1		=	0 

endif

	endin
	
;=======================================
	instr	4	; timer
;=======================================

if gkPlay != 0 goto cont
turnoff
cont:

ktinstr		timeinsts
gktinstr		= ktinstr-i(gkcdwn)

	endin
		

;=======================================
	instr	5	; timeline
;=======================================

if gkPlay != 0 goto cont
turnoff
cont:

iTime	=	p3
itime	=	1/iTime
ktime	line	itime, iTime, itime
gkph	phasor	ktime

endin

;=======================================
	instr	6	; gui-reset
;=======================================

; outvalue
outvalue	"play", 	0
outvalue	"timer", 0
outvalue 	"mtr", 0
outvalue 	"Mctwn", 0
outvalue	"revived", 0
outvalue	"capture", 0
outvalue	"timeline", 0

	turnoff
	endin
	
;=======================================
	instr	7	; gui
;=======================================

; invalue
gkin		invalue	"in"
gkcdwn	invalue 	"cdwn"

; outvalue
outvalue	"play", 	gkPlay
outvalue	"timer", gktinstr
outvalue 	"mtr", gkmtr1
outvalue 	"Mctwn", gkmtr2
outvalue	"timeline", gkph

; calculation for the conversion of the values of x and y for the Controller "RT-SPACE" in the Widgets Panel - signal in real-time
ir	=	4
kx	=	(gkx + (ir * .5)) / ir
ky	=	(gky + (ir * .5)) / ir
		
outvalue	"xout", kx
outvalue	"yout", ky
outvalue	"xdout", gkx
outvalue	"ydout", gky

; calculation for the conversion of the values of x and y for the Controller "DEL-SPACE" in the Widgets Panel - delay signal
kxD	=	(gkxD + (ir * .5)) / ir
kyD	=	(gkyD + (ir * .5)) / ir
		
outvalue	"xoutR", kxD
outvalue	"youtR", kyD
outvalue	"xdoutR", gkxD
outvalue	"ydoutR", gkyD

	endin


</CsInstruments>
<CsScore>
f0	3600
f1	0	1024	10	1
i6	0	-1
i7	.01	-1
e

</CsScore>
</CsoundSynthesizer><bsbPanel>
 <label>Widgets</label>
 <objectName/>
 <x>0</x>
 <y>44</y>
 <width>1440</width>
 <height>852</height>
 <visible>true</visible>
 <uuid/>
 <bgcolor mode="background">
  <r>202</r>
  <g>200</g>
  <b>255</b>
 </bgcolor>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>388</x>
  <y>9</y>
  <width>610</width>
  <height>109</height>
  <uuid>{951fe7d4-4247-432d-8eee-6e8889420259}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>CSOUND INSIDE
Enrico Francioni 
"Building Csound-based Systems for Realtime Chamber Music Performance"
TUTORIAL #5-07: "CLUSTER" (by E.Francioni)
example of live electronics based on timing</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>204</r>
   <g>204</g>
   <b>204</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBConsole">
  <objectName>_Console</objectName>
  <x>1006</x>
  <y>175</y>
  <width>385</width>
  <height>161</height>
  <uuid>{0dcf559d-9ef3-4913-b93c-4e9ab27d7f44}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <font>Courier</font>
  <fontsize>8</fontsize>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBButton">
  <objectName>play</objectName>
  <x>106</x>
  <y>169</y>
  <width>201</width>
  <height>80</height>
  <uuid>{ca0cee78-4c81-4fb8-80a3-cc38eeefcb03}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <type>event</type>
  <pressedValue>1.00000000</pressedValue>
  <stringvalue/>
  <text>PLAY/STOP</text>
  <image>/</image>
  <eventLine>i"Play" 0 .1</eventLine>
  <latch>true</latch>
  <latched>false</latched>
 </bsbObject>
 <bsbObject version="2" type="BSBDisplay">
  <objectName>timer</objectName>
  <x>392</x>
  <y>529</y>
  <width>600</width>
  <height>228</height>
  <uuid>{e8c4b495-5cde-4b14-893c-dcdafa4173de}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>9.999</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>180</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>128</b>
  </color>
  <bgcolor mode="background">
   <r>230</r>
   <g>230</g>
   <b>230</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>Mctwn</objectName>
  <x>89</x>
  <y>533</y>
  <width>199</width>
  <height>192</height>
  <uuid>{b23798c8-920a-46ed-97cb-92f107664948}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <objectName2>Mctwn</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.00000000</xValue>
  <yValue>0.00000000</yValue>
  <type>fill</type>
  <pointsize>8</pointsize>
  <fadeSpeed>97.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>255</r>
   <g>0</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>mtr</objectName>
  <x>1116</x>
  <y>531</y>
  <width>199</width>
  <height>192</height>
  <uuid>{c487d479-861c-4338-aea9-b8c47423bf1c}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>mtr</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.00000000</xValue>
  <yValue>0.00000000</yValue>
  <type>fill</type>
  <pointsize>8</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>255</r>
   <g>255</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>110</x>
  <y>499</y>
  <width>114</width>
  <height>32</height>
  <uuid>{a9fff42b-6a82-4ae4-b602-3adf1e1d2c00}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>count_down</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>1133</x>
  <y>496</y>
  <width>166</width>
  <height>32</height>
  <uuid>{a483e4e9-9cca-4c17-9e75-1ad743e4bed8}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>metronome</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>capture</objectName>
  <x>561</x>
  <y>163</y>
  <width>38</width>
  <height>37</height>
  <uuid>{812044cc-0eb3-496e-ade3-dadf49e39a31}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>capture</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.00000000</xValue>
  <yValue>0.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>255</r>
   <g>0</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>revived</objectName>
  <x>791</x>
  <y>163</y>
  <width>38</width>
  <height>37</height>
  <uuid>{d3285337-cf2c-4c58-ae03-701ba5956e7d}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>revived</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>1.00000000</xValue>
  <yValue>1.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>64</r>
   <g>0</g>
   <b>128</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>timeline</objectName>
  <x>87</x>
  <y>771</y>
  <width>1231</width>
  <height>51</height>
  <uuid>{0f96641e-1f32-47dd-a71f-8bfae304bb76}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>timeline</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.99990928</xValue>
  <yValue>0.99990928</yValue>
  <type>fill</type>
  <pointsize>70</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>230</r>
   <g>230</g>
   <b>230</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>88</x>
  <y>740</y>
  <width>80</width>
  <height>27</height>
  <uuid>{fd04c95e-c290-447c-a02a-b2a8c50cf201}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>time-line</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>10</fontsize>
  <precision>3</precision>
  <color>
   <r>64</r>
   <g>0</g>
   <b>128</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>1327</x>
  <y>144</y>
  <width>64</width>
  <height>28</height>
  <uuid>{e0c7e7b4-cb53-44c9-86ed-1a0d0a2689c4}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>message</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>12</fontsize>
  <precision>3</precision>
  <color>
   <r>64</r>
   <g>0</g>
   <b>128</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBDropdown">
  <objectName>in</objectName>
  <x>132</x>
  <y>310</y>
  <width>142</width>
  <height>38</height>
  <uuid>{8b34b578-361a-4ae5-a6ec-4f0632e0e2e3}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <bsbDropdownItemList>
   <bsbDropdownItem>
    <name>DEMO</name>
    <value>0</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>MIC</name>
    <value>1</value>
    <stringvalue/>
   </bsbDropdownItem>
  </bsbDropdownItemList>
  <selectedIndex>0</selectedIndex>
  <randomizable group="0">false</randomizable>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>137</x>
  <y>282</y>
  <width>132</width>
  <height>28</height>
  <uuid>{24a0bc29-1712-46fa-8321-2352ef5d85b1}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>SIGNAL</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBScrollNumber">
  <objectName>cdwn</objectName>
  <x>226</x>
  <y>499</y>
  <width>40</width>
  <height>32</height>
  <uuid>{5b6d2e2c-26b2-4e76-a6dc-dc52309af1b7}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <alignment>right</alignment>
  <font>Arial</font>
  <fontsize>20</fontsize>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <value>3.00000000</value>
  <resolution>1.00000000</resolution>
  <minimum>0.00000000</minimum>
  <maximum>10.00000000</maximum>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
  <randomizable group="0">false</randomizable>
  <mouseControl act=""/>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>525</x>
  <y>205</y>
  <width>102</width>
  <height>28</height>
  <uuid>{fa113586-59e8-4794-95a8-056ab133f118}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>CAPTURE</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>10</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>762</x>
  <y>206</y>
  <width>102</width>
  <height>28</height>
  <uuid>{84935a7f-2369-42ee-8f5f-c7f583b981ae}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>REVIVED</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>10</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>393</x>
  <y>500</y>
  <width>102</width>
  <height>28</height>
  <uuid>{c631e3cf-3aaa-4e4d-be56-ffd614949067}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>TIMER</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>10</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>476</x>
  <y>251</y>
  <width>24</width>
  <height>24</height>
  <uuid>{258d2f9a-b5f6-4ec7-8feb-82a6d388b363}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Lf</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>12</fontsize>
  <precision>3</precision>
  <color>
   <r>64</r>
   <g>0</g>
   <b>128</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBDisplay">
  <objectName>xdout</objectName>
  <x>551</x>
  <y>467</y>
  <width>51</width>
  <height>24</height>
  <uuid>{a301b24d-3987-4eab-8c1e-806443335fc6}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>10.000</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>9</fontsize>
  <precision>3</precision>
  <color>
   <r>64</r>
   <g>0</g>
   <b>128</b>
  </color>
  <bgcolor mode="nobackground">
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>xout</objectName>
  <x>475</x>
  <y>273</y>
  <width>195</width>
  <height>195</height>
  <uuid>{3f9864f6-1d12-4ca1-a625-22e5bb19f7b7}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>yout</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>3.00000000</xValue>
  <yValue>3.00000000</yValue>
  <type>point</type>
  <pointsize>9</pointsize>
  <fadeSpeed>26.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>255</r>
   <g>255</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>475</x>
  <y>463</y>
  <width>24</width>
  <height>24</height>
  <uuid>{13fb0185-1a1d-48b9-a519-d54e464458b3}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Lr</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>12</fontsize>
  <precision>3</precision>
  <color>
   <r>64</r>
   <g>0</g>
   <b>128</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBDisplay">
  <objectName>ydout</objectName>
  <x>431</x>
  <y>356</y>
  <width>43</width>
  <height>24</height>
  <uuid>{bda2949b-6c27-44e2-987b-73493f617345}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>10.000</label>
  <alignment>right</alignment>
  <font>Lucida Grande</font>
  <fontsize>9</fontsize>
  <precision>3</precision>
  <color>
   <r>64</r>
   <g>0</g>
   <b>128</b>
  </color>
  <bgcolor mode="nobackground">
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>650</x>
  <y>464</y>
  <width>24</width>
  <height>24</height>
  <uuid>{89076a50-f492-46b0-867e-7f07b07e66cd}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Rr</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>12</fontsize>
  <precision>3</precision>
  <color>
   <r>64</r>
   <g>0</g>
   <b>128</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>650</x>
  <y>249</y>
  <width>24</width>
  <height>24</height>
  <uuid>{b7c96ec6-4989-4e2d-a452-e7a2283f218e}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Rf</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>12</fontsize>
  <precision>3</precision>
  <color>
   <r>64</r>
   <g>0</g>
   <b>128</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>519</x>
  <y>246</y>
  <width>113</width>
  <height>27</height>
  <uuid>{2fbe079c-33b6-4a8e-91a2-d15fb4b09428}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>RT-SPACE</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>713</x>
  <y>249</y>
  <width>24</width>
  <height>24</height>
  <uuid>{ee27534e-7f07-42dd-ae06-bab75eef6352}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Lf</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>12</fontsize>
  <precision>3</precision>
  <color>
   <r>64</r>
   <g>0</g>
   <b>128</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>xoutR</objectName>
  <x>714</x>
  <y>272</y>
  <width>195</width>
  <height>195</height>
  <uuid>{b07fec51-0148-4f9c-9ff2-06af505f96ad}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>youtR</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.25000000</xValue>
  <yValue>0.75000000</yValue>
  <type>point</type>
  <pointsize>9</pointsize>
  <fadeSpeed>26.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>255</r>
   <g>102</g>
   <b>255</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBDisplay">
  <objectName>ydoutR</objectName>
  <x>673</x>
  <y>354</y>
  <width>44</width>
  <height>24</height>
  <uuid>{599d0cca-2dde-43b2-9e21-94f9fffb0e46}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>1.000</label>
  <alignment>right</alignment>
  <font>Lucida Grande</font>
  <fontsize>9</fontsize>
  <precision>3</precision>
  <color>
   <r>64</r>
   <g>0</g>
   <b>128</b>
  </color>
  <bgcolor mode="nobackground">
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>888</x>
  <y>250</y>
  <width>24</width>
  <height>24</height>
  <uuid>{e387d2f1-372e-46e7-8c8c-8884e1d69a53}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Rf</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>12</fontsize>
  <precision>3</precision>
  <color>
   <r>64</r>
   <g>0</g>
   <b>128</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>711</x>
  <y>465</y>
  <width>24</width>
  <height>24</height>
  <uuid>{f2541e9c-10e9-4f2f-a53a-371e28be35eb}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Lr</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>12</fontsize>
  <precision>3</precision>
  <color>
   <r>64</r>
   <g>0</g>
   <b>128</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>887</x>
  <y>464</y>
  <width>24</width>
  <height>24</height>
  <uuid>{7bb2f2c4-47ed-4479-8729-f8e3f8059215}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Rr</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>12</fontsize>
  <precision>3</precision>
  <color>
   <r>64</r>
   <g>0</g>
   <b>128</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBDisplay">
  <objectName>xdoutR</objectName>
  <x>791</x>
  <y>466</y>
  <width>51</width>
  <height>24</height>
  <uuid>{db635562-560c-4236-b510-0df40059943e}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>-1.000</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>9</fontsize>
  <precision>3</precision>
  <color>
   <r>64</r>
   <g>0</g>
   <b>128</b>
  </color>
  <bgcolor mode="nobackground">
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>757</x>
  <y>245</y>
  <width>113</width>
  <height>27</height>
  <uuid>{2f5cf5f9-f755-4b8d-8517-54da50b8cc4b}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>DEL-SPACE</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
</bsbPanel>
<bsbPresets>
</bsbPresets>
<MacOptions>
Version: 3
Render: Real
Ask: Yes
Functions: ioObject
Listing: Window
WindowBounds: 72 179 400 200
CurrentView: io
IOViewEdit: On
Options:
</MacOptions>

<MacGUI>
ioView background {51914, 51400, 65535}
ioText {388, 9} {610, 109} label 0.000000 0.00100 "" center "Arial" 14 {0, 0, 0} {52224, 52224, 52224} nobackground noborder CSOUND INSIDEÂ¬Enrico Francioni Â¬"Building Csound-based Systems for Realtime Chamber Music Performance"Â¬TUTORIAL #5-07: "CLUSTER" (by E.Francioni)Â¬example of live electronics based on timing
ioListing {1006, 175} {385, 161}
ioButton {106, 169} {201, 80} event 1.000000 "play" "PLAY/STOP" "/" i"Play" 0 .1
ioText {392, 529} {600, 228} display 9.999000 0.00100 "timer" center "Lucida Grande" 180 {0, 0, 32768} {58880, 58880, 58880} nobackground noborder 9.999
ioMeter {89, 533} {199, 192} {65280, 0, 0} "Mctwn" 0.000000 "Mctwn" 0.000000 fill 8 0 mouse
ioMeter {1116, 531} {199, 192} {65280, 65280, 0} "mtr" 0.000000 "mtr" 0.000000 fill 8 0 mouse
ioText {110, 499} {114, 32} label 0.000000 0.00100 "" center "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder count_down
ioText {1133, 496} {166, 32} label 0.000000 0.00100 "" center "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder metronome
ioMeter {561, 163} {38, 37} {65280, 0, 0} "capture" 0.000000 "capture" 0.000000 fill 1 0 mouse
ioMeter {791, 163} {38, 37} {16384, 0, 32768} "revived" 1.000000 "revived" 1.000000 fill 1 0 mouse
ioMeter {87, 771} {1231, 51} {58880, 58880, 58880} "timeline" 0.999909 "timeline" 0.999909 fill 70 0 mouse
ioText {88, 740} {80, 27} label 0.000000 0.00100 "" center "Lucida Grande" 10 {16384, 0, 32768} {65280, 65280, 65280} nobackground noborder time-line
ioText {1327, 144} {64, 28} label 0.000000 0.00100 "" center "Lucida Grande" 12 {16384, 0, 32768} {65280, 65280, 65280} nobackground noborder message
ioMenu {132, 310} {142, 38} 0 303 "DEMO,MIC" in
ioText {137, 282} {132, 28} label 0.000000 0.00100 "" center "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder SIGNAL
ioText {226, 499} {40, 32} scroll 3.000000 1.000000 "cdwn" right "Arial" 20 {0, 0, 0} {65280, 65280, 65280} background noborder 
ioText {525, 205} {102, 28} label 0.000000 0.00100 "" center "Arial" 10 {0, 0, 0} {65280, 65280, 65280} nobackground noborder CAPTURE
ioText {762, 206} {102, 28} label 0.000000 0.00100 "" center "Arial" 10 {0, 0, 0} {65280, 65280, 65280} nobackground noborder REVIVED
ioText {393, 500} {102, 28} label 0.000000 0.00100 "" center "Arial" 10 {0, 0, 0} {65280, 65280, 65280} nobackground noborder TIMER
ioText {476, 251} {24, 24} label 0.000000 0.00100 "" center "Lucida Grande" 12 {16384, 0, 32768} {65280, 65280, 65280} nobackground noborder Lf
ioText {551, 467} {51, 24} display 10.000000 0.00100 "xdout" center "Lucida Grande" 9 {16384, 0, 32768} {65280, 65280, 65280} nobackground noborder 10.000
ioMeter {475, 273} {195, 195} {65280, 65280, 0} "xout" 3.000000 "yout" 3.000000 point 9 0 mouse
ioText {475, 463} {24, 24} label 0.000000 0.00100 "" center "Lucida Grande" 12 {16384, 0, 32768} {65280, 65280, 65280} nobackground noborder Lr
ioText {431, 356} {43, 24} display 10.000000 0.00100 "ydout" right "Lucida Grande" 9 {16384, 0, 32768} {65280, 65280, 65280} nobackground noborder 10.000
ioText {650, 464} {24, 24} label 0.000000 0.00100 "" center "Lucida Grande" 12 {16384, 0, 32768} {65280, 65280, 65280} nobackground noborder Rr
ioText {650, 249} {24, 24} label 0.000000 0.00100 "" center "Lucida Grande" 12 {16384, 0, 32768} {65280, 65280, 65280} nobackground noborder Rf
ioText {519, 246} {113, 27} label 0.000000 0.00100 "" center "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder RT-SPACE
ioText {713, 249} {24, 24} label 0.000000 0.00100 "" center "Lucida Grande" 12 {16384, 0, 32768} {65280, 65280, 65280} nobackground noborder Lf
ioMeter {714, 272} {195, 195} {65280, 26112, 65280} "xoutR" 0.250000 "youtR" 0.750000 point 9 0 mouse
ioText {673, 354} {44, 24} display 1.000000 0.00100 "ydoutR" right "Lucida Grande" 9 {16384, 0, 32768} {65280, 65280, 65280} nobackground noborder 1.000
ioText {888, 250} {24, 24} label 0.000000 0.00100 "" center "Lucida Grande" 12 {16384, 0, 32768} {65280, 65280, 65280} nobackground noborder Rf
ioText {711, 465} {24, 24} label 0.000000 0.00100 "" center "Lucida Grande" 12 {16384, 0, 32768} {65280, 65280, 65280} nobackground noborder Lr
ioText {887, 464} {24, 24} label 0.000000 0.00100 "" center "Lucida Grande" 12 {16384, 0, 32768} {65280, 65280, 65280} nobackground noborder Rr
ioText {791, 466} {51, 24} display -1.000000 0.00100 "xdoutR" center "Lucida Grande" 9 {16384, 0, 32768} {65280, 65280, 65280} nobackground noborder -1.000
ioText {757, 245} {113, 27} label 0.000000 0.00100 "" center "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder DEL-SPACE
</MacGUI>
