
/*
tutorial_#6-01

=====================
Six Online Tutorials:
=====================

The tutorials online propose ideas and approaches, which allow the user to problematize and then practice to do something to use for their own purposes.
Describes the stages of construction of some systems to help the reader, step by step, to learn to do something, to build patchs be used effectively in the performance.
Examples are some ideas to change, expand, or start from scratch using the same ideas or the same solutions and then realize their control systems.

=====================
ONLINE TUTORIAL #6
6. "eSpace" (by E.Francioni) - example of realtime spatialization of multichannel signals.
=====================

The group tutorial_#6 is dedicated to examples of spatial signal in a quadraphonic sound system.
The examples are taken from a larger patch ["eSpace"] in which the spatial signal in real time may occur in a programmed or free.
N.B. For successful execution of the algorithm with spatial 4-channel [nchnls = 4] is necessary to interface a sound card to 4 output channels and one input channel; alternatively it is important to keep nchnls = 2.

***

In this tutorial_#6-01 the signal is "conducted" in a linear directions in space quadraphonic so programmed.

Some observations: 
    in the orchestra 
    - opcode space manages the spatial quadraphonic signal through the arguments kx and ky; 
    - Export values kx and ky in GUI is needed the process of converting to the values as the coordinate plane; 
    
    in the Widgets Panel 
    - we start instr 1 with Button "Lines"; 
    - We can follow the behavior of the signal in space quadraphonic through movement of the Point within the Controller.

*/

<CsoundSynthesizer>
<CsOptions>
</CsOptions>
<CsInstruments>

; header
sr		=	44100
ksmps		=	64
nchnls		=	2
;nchnls		=	4
0dbfs		=	1

;===========================================
	instr 1 	; LINEAR DIRECTIONS
;===========================================

asig		rand	.7	; signal (test)

; initialization step to replicate the signal path

reset:
idur_seg 	= p3/2
idur		= idur_seg * (1/9) 

ia		=	-1
ib		=	1

kx linseg ia, idur, ib, idur, ib, idur, ia, idur, ia, idur, ib, idur, ib, idur, ia, idur, ib, idur, ia	; segment x
ky linseg ib, idur, ib, idur, ia, idur, ia, idur, ib, idur, ia, idur, ib, idur, ia, idur, ia, idur, ib	; segment y

timout 0, idur_seg, continue
reinit reset
continue:
rireturn

a1, a2, a3, a4	space	asig, 0, 0, 0, kx, ky		; spatial quadraphonic signal

ir		=	2.25				; conversion value for the Controller in the Widgets Panel
kx_c	=	(kx + (ir * .5)) / ir			; kx conversion values for the Controller
ky_c	=	(ky + (ir * .5)) / ir			; ky conversion values for the Controller

		outvalue	"x2out", kx_c		; export values in the Controller
		outvalue	"y2out", ky_c		; export values in the Controller
		outvalue	"xd2out", kx		; export values in Display
		outvalue	"yd2out", ky		; export values in Display

outch	1, a1, 2, a2, 3, a3, 4, a4			; audio output of four channels

endin

</CsInstruments>
<CsScore>
e 3600

</CsScore>
</CsoundSynthesizer><bsbPanel>
 <label>Widgets</label>
 <objectName/>
 <x>0</x>
 <y>66</y>
 <width>1441</width>
 <height>856</height>
 <visible>true</visible>
 <uuid/>
 <bgcolor mode="background">
  <r>91</r>
  <g>91</g>
  <b>91</b>
 </bgcolor>
 <bsbObject version="2" type="BSBButton">
  <objectName/>
  <x>123</x>
  <y>55</y>
  <width>115</width>
  <height>45</height>
  <uuid>{1cfeefbb-94e9-4445-9f8b-25532a1c60cd}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <type>event</type>
  <pressedValue>1.00000000</pressedValue>
  <stringvalue/>
  <text>Lines</text>
  <image>/</image>
  <eventLine>i1 0 15</eventLine>
  <latch>false</latch>
  <latched>false</latched>
 </bsbObject>
 <bsbObject version="2" type="BSBController">
  <objectName>x2out</objectName>
  <x>78</x>
  <y>102</y>
  <width>195</width>
  <height>195</height>
  <uuid>{707fb675-3e10-421e-ac1e-07c2d197da3d}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>y2out</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.05555556</xValue>
  <yValue>0.94444442</yValue>
  <type>point</type>
  <pointsize>6</pointsize>
  <fadeSpeed>35.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>255</r>
   <g>255</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>58</x>
  <y>78</y>
  <width>24</width>
  <height>24</height>
  <uuid>{d926e46f-3c78-4b57-861b-d009b5dc998c}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>Lf</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>10</fontsize>
  <precision>3</precision>
  <color>
   <r>230</r>
   <g>230</g>
   <b>230</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>272</x>
  <y>80</y>
  <width>24</width>
  <height>24</height>
  <uuid>{306f3527-44e4-4708-b067-75442045e22d}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>Rf</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>10</fontsize>
  <precision>3</precision>
  <color>
   <r>230</r>
   <g>230</g>
   <b>230</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>272</x>
  <y>295</y>
  <width>24</width>
  <height>24</height>
  <uuid>{3df97e25-a818-47a9-9772-86a996d6b42f}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>Rr</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>10</fontsize>
  <precision>3</precision>
  <color>
   <r>230</r>
   <g>230</g>
   <b>230</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>56</x>
  <y>293</y>
  <width>24</width>
  <height>24</height>
  <uuid>{b225fba9-f41f-4ec5-ab23-6e8b420c89a9}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>Lr</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>10</fontsize>
  <precision>3</precision>
  <color>
   <r>230</r>
   <g>230</g>
   <b>230</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>432</x>
  <y>6</y>
  <width>511</width>
  <height>104</height>
  <uuid>{951fe7d4-4247-432d-8eee-6e8889420259}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>CSOUND INSIDE
Enrico Francioni 
"Building Csound-based Systems for Realtime Chamber Music Performance"
TUTORIAL #6-01: "eSpace" (by E.Francioni) - example of realtime spatialization of multichannel signals.</label>
  <alignment>center</alignment>
  <font>Arial</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>204</r>
   <g>204</g>
   <b>204</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBDisplay">
  <objectName>yd2out</objectName>
  <x>3</x>
  <y>184</y>
  <width>82</width>
  <height>23</height>
  <uuid>{f134650b-a01d-466b-ac44-5a396487d801}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>1.000</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>8</fontsize>
  <precision>3</precision>
  <color>
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </color>
  <bgcolor mode="nobackground">
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBDisplay">
  <objectName>xd2out</objectName>
  <x>140</x>
  <y>298</y>
  <width>71</width>
  <height>25</height>
  <uuid>{8b3a6861-d4a5-4a05-b0f4-072ab6a14d27}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>-1.000</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>8</fontsize>
  <precision>3</precision>
  <color>
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </color>
  <bgcolor mode="nobackground">
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>163</x>
  <y>317</y>
  <width>24</width>
  <height>24</height>
  <uuid>{66ced349-5c9b-46b3-a03b-8a68da8c9e88}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>x</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>10</fontsize>
  <precision>3</precision>
  <color>
   <r>230</r>
   <g>230</g>
   <b>230</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>32</x>
  <y>159</y>
  <width>24</width>
  <height>24</height>
  <uuid>{f5ab5e7b-df29-4baf-80b1-f37ad6b55e51}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>y</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>10</fontsize>
  <precision>3</precision>
  <color>
   <r>230</r>
   <g>230</g>
   <b>230</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
</bsbPanel>
<bsbPresets>
</bsbPresets>
<MacOptions>
Version: 3
Render: Real
Ask: Yes
Functions: ioObject
Listing: Window
WindowBounds: 72 179 400 200
CurrentView: io
IOViewEdit: On
Options:
</MacOptions>

<MacGUI>
ioView background {23387, 23387, 23387}
ioButton {123, 55} {115, 45} event 1.000000 "" "Lines" "/" i1 0 15
ioMeter {78, 102} {195, 195} {65280, 65280, 0} "x2out" 0.055556 "y2out" 0.944444 point 6 0 mouse
ioText {58, 78} {24, 24} label 0.000000 0.00100 "" center "Lucida Grande" 10 {58880, 58880, 58880} {65280, 65280, 65280} nobackground noborder Lf
ioText {272, 80} {24, 24} label 0.000000 0.00100 "" center "Lucida Grande" 10 {58880, 58880, 58880} {65280, 65280, 65280} nobackground noborder Rf
ioText {272, 295} {24, 24} label 0.000000 0.00100 "" center "Lucida Grande" 10 {58880, 58880, 58880} {65280, 65280, 65280} nobackground noborder Rr
ioText {56, 293} {24, 24} label 0.000000 0.00100 "" center "Lucida Grande" 10 {58880, 58880, 58880} {65280, 65280, 65280} nobackground noborder Lr
ioText {432, 6} {511, 104} label 0.000000 0.00100 "" center "Arial" 14 {0, 0, 0} {52224, 52224, 52224} nobackground noborder CSOUND INSIDEÂ¬Enrico Francioni Â¬"Building Csound-based Systems for Realtime Chamber Music Performance"Â¬TUTORIAL #6-01: "eSpace" (by E.Francioni) - example of realtime spatialization of multichannel signals.
ioText {3, 184} {82, 23} display 1.000000 0.00100 "yd2out" center "Lucida Grande" 8 {65280, 65280, 65280} {65280, 65280, 65280} nobackground noborder 1.000
ioText {140, 298} {71, 25} display -1.000000 0.00100 "xd2out" center "Lucida Grande" 8 {65280, 65280, 65280} {65280, 65280, 65280} nobackground noborder -1.000
ioText {163, 317} {24, 24} label 0.000000 0.00100 "" center "Lucida Grande" 10 {58880, 58880, 58880} {65280, 65280, 65280} nobackground noborder x
ioText {32, 159} {24, 24} label 0.000000 0.00100 "" center "Lucida Grande" 10 {58880, 58880, 58880} {65280, 65280, 65280} nobackground noborder y
</MacGUI>
